package net.knarcraft.serverlauncher.server;

import javax.naming.ConfigurationException;
import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.Scanner;

/**
 * Contains the bare minimum to be a functional servertype.
 *
 * @author		Kristian Knarvik <kristian.knarvik@knett.no>
 * @version	0.0.0.1
 * @since		0.0.0.1
 */
public class ServerType {
	private final String name;
	private final String[] versions;
	private final String downloadURL;
	private static ArrayList<ServerType> serverTypes = new ArrayList<>();
	
	public ServerType(String name, String[] versions, String downloadURL) {
		this.name = name;
		this.versions = versions;
		this.downloadURL = downloadURL;
		serverTypes.add(this);
	}
	
	public String getName() {
		return this.name;
	}
	
	public String[] getVersions() {
		return this.versions;
	}

	public String getDownloadURL() {
		return this.downloadURL;
	}

	public static ArrayList<ServerType> getServerTypes() {
		return serverTypes;
	}

	/**
	 * Reads valid server types and version from a file, and creates their objects.
	 *
	 * @throws ConfigurationException if anything goes wrong.
	 */
	public static void loadServerTypes() throws ConfigurationException {
		if (serverTypes.isEmpty()) {
			try (Scanner in = new Scanner(new File("config/servertypes.csv"))) {
				while (in.hasNextLine()) {
					String[] str = in.nextLine().split(";", -1);
					int len = str.length;
					String[] ver;
					if (str[1].contains(",")) {
						ver = str[1].split(",", -1);
					} else {
						ver = new String[]{str[1]};
					}
					if (len == 7) {
						new AdvancedServerType(str[0], ver, str[2], str[3], str[4], str[5], str[6]);
					} else if (len == 3) {
						new ServerType(str[0], ver, str[2]);
					} else {
						throw new ConfigurationException("Error: Configuration file invalid.");
					}
				}
			} catch (FileNotFoundException e) {
				throw new ConfigurationException("Error: Configuration file not found.");
			} catch (ArrayIndexOutOfBoundsException e) {
				throw new ConfigurationException("Error: Configuration file invalid.");
			}
		} else {
			throw new ConfigurationException("Error: Configuration already loaded.");
		}
	}
}